Skip site navigation (1)Skip section navigation (2)

  
 
  

home | help
VNSTATI(1)			  User Manuals			      VNSTATI(1)

NAME
     vnstati - image output support for vnStat

SYNOPSIS
     vnstati  [-5bcdDehiLmosStvy?]  [--95th mode] [-5g [limit] [height]] [--alt-
     date] [--begin date] [--cache time] [--config file] [--days [limit]]  [--db
     file]  [--dbdir  directory]  [--dbiflist  [mode]]	[--debug]  [--end  date]
     [--fivegraph [limit] [height]] [--fiveminutes [limit]] [--headertext  text]
     [--help] [-hg [mode]] [--hours [limit]] [--hoursgraph [mode]] [-hs [graph]]
     [--hsummary [graph]] [-i interface] [--iface interface] [-ic [mode]] [--in-
     vert-colors  [mode]]  [--large] [--limit limit] [--locale locale] [--months
     [limit]] [-ne] [-nh] [-nl] [--noedge] [--noheader]  [--nolegend]  [--output
     file] [-ru [mode]] [--rateunit [mode]] [--scale percent] [--small] [--style
     number]  [--summary]  [--top [limit]] [--transparent [enabled]] [--version]
     [-vs [graph]] [--vsummary [graph]] [--months [limit]] [interface]

DESCRIPTION
     The purpose of vnstati is to provide image output	support  for  statistics
     collected using vnstat(1).  The available image file formats depend on what
     is  supported  by the used GD library. All basic outputs of vnStat are sup-
     ported excluding live traffic features. The image can be  outputted  either
     to  a file or to standard output, with the later being limited to png image
     format.

OPTIONS
     --95th mode
	    Show 95th percentile output graph for the ongoing month. This output
	    uses the 5 minute resolution data of the ongoing month to  calculate
	    the  95th percentile traffic rate for received, transmitted or total
	    as selected using the mandatory mode parameter. The 95th  percentile
	    will  be shown as a horizontal line in the graph with the exact 95th
	    percentile traffic rate visible in the legend section of the  image.
	    In	addition,  a one hour resolution traffic rate bar graph averaged
	    from the 5 minute resolution data of the selected mode is presented.
	    This output requires the 5MinuteHours configuration option to have a
	    value of at least 744 for storing all the necessary data,  otherwise
	    100%  coverage  isn't  possible.  Available modes: 0 = received, 1 =
	    transmitted, 2 = total.

     --altdate
	    Use alternative date and time text location. The date and time  text
	    will  be moved from the upper right header section to the lower left
	    corner. This option will have no effect if -nh, --noheader has  been
	    selected.

     -b, --begin date
	    Begin  the	list  output with a specific date / time defined by date
	    instead of the begin being selected based on the number  of  entries
	    to be shown.  If date isn't available in the database then the clos-
	    est  later	date will be used.  date supports the following formats:
	    YYYY-MM-DD HH:MM, YYYY-MM-DD and "today".  This option can	only  be
	    used with list outputs.

     -c, --cache time
	    Update  output  file only if at least time minutes have passed since
	    the previous file update. This option is ignored if stdout	is  used
	    as output.

     --config file
	    Use file as configuration file instead of using automatic configura-
	    tion file search functionality.  If --config is used multiple times,
	    the configuration settings from files later on the command line will
	    override  configuration  settings  loaded  from earlier files if the
	    settings defined in the files overlap.

     -d, --days [limit]
	    Output traffic statistics on a daily basis for the	last  days.  The
	    length  of	the list will be limited to 30 entries unless configured
	    otherwise or unless the optional limit parameter is  used.	All  en-
	    tries stored in the database will be shown if limit is set to 0.

     --db file
	    Use  file  as database file instead of searching for a database from
	    the directory specified in the configuration file or  the  hardcoded
	    default  if  no  configuration file is available.  This option over-
	    rides --dbdir.

     --dbdir directory
	    Use directory as database directory instead of using  the  directory
	    specified  in  the configuration file or the hardcoded default if no
	    configuration file is available. This option is ignored if	--db  is
	    also defined.

     --dbiflist [mode]
	    List interfaces currently in the database. If mode is not defined or
	    is	set  to 0 then the output will use a one line verbose format. If
	    mode is set to 1 then the output will contain one interface per line
	    and if mode is set to 2 then only the interface count will be  shown
	    as a single number. See also --iflist.

     -D, --debug
	    Show additional debug output.

     -e, --end date
	    End  the list output with a specific date / time defined by date in-
	    stead of the latest date / time  in  the  database.  If  date  isn't
	    available  in  the	database  then	the closest earlier date will be
	    used.  date supports the following	formats:  YYYY-MM-DD  HH:MM  and
	    YYYY-MM-DD.  This option can only be used with list outputs. The top
	    list also requires --begin to be used at the same time with this op-
	    tion.

     -5g, --fivegraph [limit] [height]
	    Output traffic statistics with a 5 minute resolution for the last 48
	    hours  using a bar graph. The width of the graph can be modified us-
	    ing the optional limit parameter which represents the  number  of  5
	    minute entries with 12 entries for each hour. The smallest supported
	    value  is 288 (last 24 hours). Additionally, the height of the graph
	    can be modified using the optional height  parameter.  The	smallest
	    supported height is 150 pixels.

     -5, --fiveminutes [limit]
	    Output  traffic  statistics  with a 5 minute resolution for the last
	    hours.  The length of the list will be limited to 24 entries  unless
	    configured otherwise or unless the optional limit parameter is used.
	    All  entries stored in the database will be shown if limit is set to
	    0.

     --headertext text
	    Show text in image header section instead of automatically generated
	    interface identification.  text is limited to 64 characters and  may
	    not  get completely shown if longer than the width of the image. Use
	    with --altdate if maximal space is needed. This option will have  no
	    effect if -nh, --noheader has been selected.

     -h, --hours [limit]
	    Output  traffic statistics on a hourly basis. The length of the list
	    will be limited to 24 entries unless configured otherwise or  unless
	    the optional limit parameter is used. All entries store in the data-
	    base will be shown if the limit is set to 0.

     -hg, --hoursgraph [mode]
	    Output  traffic  statistics  on a hourly basis for the last 24 hours
	    using a bar graph.	The optional mode parameter can be used to over-
	    ride the configuration file setting. Available modes: 0  =	24  hour
	    sliding window, 1 = graph begins from midnight.

     -hs, --hsummary [graph]
	    Output  traffic  summary  with the graph selected using the Summary-
	    Graph setting in the configuration file next to it using a	horizon-
	    tal layout. The optional graph parameter can be used to override the
	    configuration  file setting. Available graphs: 0 = hours, 1 = 5 min-
	    utes.

     -i, --iface interface
	    Use interface instead of default or configured interface. It is also
	    possible to merge the information of two or  more  interfaces  using
	    the  interface1+interface2+...  syntax. All provided interfaces must
	    be unique and must exist in the database when the  merge  syntax  is
	    used.  Optionally,	depending on the InterfaceMatchMethod configura-
	    tion setting, interface can be replaced with  alias  previously  set
	    using vnstat --setalias.  Merge syntax isn't supported when alias is
	    used.  The	-i, --iface option is optional and interface can be used
	    as parameter on the command line for selecting  the  used  interface
	    even without the option being explicitly used.

     -ic, --invert-colors [mode]
	    Invert  image  colors.  Results in black becoming white, dark colors
	    becoming light, light colors becoming dark and white becoming black.
	    The optional mode parameter can be used to change the  color  inver-
	    sion  behaviour. Available modes: 0 = no color inversion, 1 = invert
	    all colors except those used for rx and tx, 2 = invert  all  colors.
	    When mode isn't specific, mode 1 will be used.

     -L, --large
	    Use large fonts in output.

     --limit limit
	    Set  the  maximum  number of shown entries in list outputs to limit.
	    Usage of --limit overrides the default list entry limit  values  and
	    the  optional  limit  parameter given directly for a list query. All
	    entries stored in the database will be shown if limit is set to 0.

     --locale locale
	    Use locale instead of using the locale setting specified in the con-
	    figuration file or the system default if no  configuration	file  is
	    available.

     -m, --months [limit]
	    Output  traffic  statistics  on a monthly basis for the last months.
	    The length of the list will be limited to 12 entries unless  config-
	    ured  otherwise  or unless the optional limit parameter is used. All
	    entries stored in the database will be shown if limit is set to 0.

     -ne, --noedge
	    Remove darker edges from around the image.

     -nh, --noheader
	    Remove header containing title and update time. Time of the previous
	    update will still be visible in the lower right corner using a  less
	    visible color.

     -nl, --nolegend
	    Remove  legend  containing	rx and tx color mapping information from
	    the image.

     -o, --output file
	    Write image to file and exit. The used image format is  selected  by
	    the  given file extension of file.	For example, "image.png" results
	    in the file getting written using the png image format  due  to  the
	    ".png" extension having been used. Usage of png image format usually
	    results  in  the smallest file size without loss of detail or intro-
	    duction of compression artifacts. Alternatively, output can  be  di-
	    rected  to stdout by giving "-" as file in which case png image for-
	    mat is used.

     -ru, --rateunit [mode]
	    Swap the configured rate unit. If rate has	been  configured  to  be
	    shown  in  bytes  then  rate will be shown in bits if this option is
	    present. In the same way, if rate has been configured to be shown in
	    bits then rate will be shown in bytes when this option  is	present.
	    Alternatively,  mode with either 0 or 1 can be used as parameter for
	    this option in order to select between bytes (0) and  bits	(1)  re-
	    gardless of the configuration file setting.

     --scale percent
	    Scale  output  to  given percent resulting in the image being either
	    smaller or larger than the default size.

     -S, --small
	    Use small fonts in output.

     --style number
	    Modify the content and style of outputs. Setting number  to  3  will
	    show  average  traffic  rate  in  all outputs where it is supported.
	    Other values will show bar graphics instead.

     -s, --summary
	    Output traffic statistics summary.

     -t, --top [limit]
	    Output all time top traffic days. The length of  the  list	will  be
	    limited  to 10 entries unless configured otherwise or unless the op-
	    tional limit parameter is used. All entries stored in  the	database
	    will  be  shown if limit is set to 0. When used with --begin and op-
	    tionally with --end, the list will be generated using the daily data
	    instead of separate top entries.  The availability of daily data de-
	    fines the boundaries the date specific query can access.

     --transparent [enabled]
	    Toggle background color transparency depending of the  TransparentBg
	    setting  in  the  configuration  file.  Alternatively, 0 or 1 can be
	    given as parameter enabled for this option in order to  either  dis-
	    able  (0) or enable (1) transparency regardless of the configuration
	    file setting.

     -v, --version
	    Show current version.

     -vs, --vsummary [graph]
	    Output traffic summary with the graph selected  using  the	Summary-
	    Graph  setting  in	the configuration file below it using a vertical
	    layout. The optional graph parameter can be  used  to  override  the
	    configuration  file setting. Available graphs: 0 = hours, 1 = 5 min-
	    utes.

     -y, --years [limit]
	    Output traffic statistics on a yearly basis for the last years.  The
	    list will show all entries by default unless configured otherwise or
	    unless  the  optional limit parameter is used. All entries stored in
	    the database will also be shown if limit is set to 0.

     -?, --help
	    Show a command option summary.

FILES
     /var/lib/vnstat/
	    Default database directory.

     /etc/vnstat.conf
	    Config file that will be used unless $HOME/.vnstatrc exists. See vn-
	    stat.conf(5) for more information.

EXAMPLES
     vnstati -s -i eth0 -o /tmp/vnstat.png
	    Output traffic summary for interface eth0 to file /tmp/vnstat.png.

     vnstati -vs -i eth0+eth1+eth2 -o /tmp/vnstat.png
	    Output traffic summary with hourly data under the normal summary for
	    a merge of interfaces eth0, eth1 and eth2 to file /tmp/vnstat.png.

     vnstati -h -c 15 -o /tmp/vnstat_h.png
	    Output hourly traffic  statistics  for  default  interface	to  file
	    /tmp/vnstat_h.png  if  the file has not been updated within the last
	    15 minutes.

     vnstati -d -ne -nh -o -
	    Output daily traffic statistics without displaying the  header  sec-
	    tion and edges for default interface to standard output (stdout).

     vnstati -m --config /home/me/vnstat.cfg -i -o -
	    Output monthly traffic statistics for default interface specified in
	    configuration file /home/me/vnstat.cfg to standard output (stdout).

RESTRICTIONS
     Depending on the built-in fonts provided by the GD library, not all charac-
     ters may end up shown correctly when a UTF-8 locale is used.

     Using  long  date output formats may cause misalignment in shown columns if
     the length of the date exceeds the fixed size allocation.

     Scaling an image when background transparency is enabled may not result  in
     transparency being retained.

AUTHOR
     Teemu Toivola <tst at iki dot fi>

SEE ALSO
     vnstat(1), vnstatd(8), vnstat.conf(5), units(7)

version 2.13			  FEBRUARY 2025 		      VNSTATI(1)

Want to link to this manual page? Use this URL:
<https://man.freebsd.org/cgi/man.cgi?query=vnstati&sektion=1&manpath=FreeBSD+Ports+15.1.quarterly>

home | help